@@ -52,14 +52,14 @@ class Datastore:
         created: datetime = datetime.now(timezone.utc),
         name: Optional[str] = None,
     ) -> "Bucket":
-        self.logger.info("Creating bucket '{}'".format(bucket_id))
+        self.logger.info(f"Creating bucket '{bucket_id}'")
         self.storage_strategy.create_bucket(
             bucket_id, type, client, hostname, created.isoformat(), name=name
         )
         return self[bucket_id]
 
     def delete_bucket(self, bucket_id: str):
-        self.logger.info("Deleting bucket '{}'".format(bucket_id))
+        self.logger.info(f"Deleting bucket '{bucket_id}'")
         if bucket_id in self.bucket_instances:
             del self.bucket_instances[bucket_id]
         return self.storage_strategy.delete_bucket(bucket_id)
@@ -102,6 +102,10 @@ class Bucket:
             self.bucket_id, limit, starttime, endtime
         )
 
+    def get_by_id(self, event_id) -> Optional[Event]:
+        """Will return the event with the provided ID, or None if not found."""
+        return self.ds.storage_strategy.get_event(self.bucket_id, event_id)
+
     def get_eventcount(
         self, starttime: datetime = None, endtime: datetime = None
     ) -> int:
