@@ -117,13 +117,13 @@ class PeeweeStorage(AbstractStorage):
             filename = (
                 "peewee-sqlite"
                 + ("-testing" if testing else "")
-                + ".v{}".format(LATEST_VERSION)
+                + f".v{LATEST_VERSION}"
                 + ".db"
             )
             filepath = os.path.join(data_dir, filename)
         self.db = _db
         self.db.init(filepath)
-        logger.info("Using database file: {}".format(filepath))
+        logger.info(f"Using database file: {filepath}")
 
         self.db.connect()
 
@@ -212,13 +212,16 @@ class PeeweeStorage(AbstractStorage):
         for chunk in chunks(events_dictlist, 100):
             EventModel.insert_many(chunk).execute()
 
-    def _get_event(self, bucket_id, event_id) -> EventModel:
-        return (
-            EventModel.select()
-            .where(EventModel.id == event_id)
-            .where(EventModel.bucket == self.bucket_keys[bucket_id])
-            .get()
-        )
+    def _get_event(self, bucket_id, event_id) -> Optional[EventModel]:
+        try:
+            return (
+                EventModel.select()
+                .where(EventModel.id == event_id)
+                .where(EventModel.bucket == self.bucket_keys[bucket_id])
+                .get()
+            )
+        except peewee.DoesNotExist:
+            return None
 
     def _get_last(self, bucket_id) -> EventModel:
         return (
@@ -254,6 +257,17 @@ class PeeweeStorage(AbstractStorage):
         event.id = e.id
         return event
 
+    def get_event(
+        self,
+        bucket_id: str,
+        event_id: int,
+    ) -> Optional[Event]:
+        """
+        Fetch a single event from a bucket.
+        """
+        res = self._get_event(bucket_id, event_id)
+        return Event(**EventModel.json(res)) if res else None
+
     def get_events(
         self,
         bucket_id: str,
